======================================
NIXIO Python Package for NIX Datafiles
======================================

The nixpy module contains the python binding to the nix c++ library. In order
to use it you also have to have the nix library installed. 


Getting started
===============

The following sections should help you getting started with nixpy. 

.. toctree::
   :maxdepth: 2

   install
   overview
   tutorial

API Documentation
=================
The API documentation for Data and Metadata

.. toctree::
   :maxdepth: 2

   api_data
   api_metadata

